PebbleServices

Struct PebbleServices 

pub struct PebbleServices {
    pub accelerometer: AccelerometerService,
    pub app_messages: AppMessages,
}
A collection of PebbleOS services that have global configuration, and therefore need to be configured from a single location.

An instance of this struct will be given to you by the main macro.

Fields

accelerometer: AccelerometerServiceapp_messages: AppMessages