pub struct PebbleServices {
pub accelerometer: AccelerometerService,
pub app_messages: AppMessages,
}Expand description
A collection of PebbleOS services that have global configuration, and therefore need to be configured from a single location.
An instance of this struct will be given to you by the main macro.
Fields
accelerometer: AccelerometerServiceapp_messages: AppMessagesAuto Trait Implementations
impl Freeze for PebbleServices
impl RefUnwindSafe for PebbleServices
impl Send for PebbleServices
impl Sync for PebbleServices
impl Unpin for PebbleServices
impl UnsafeUnpin for PebbleServices
impl UnwindSafe for PebbleServices